'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var installer_1 = require("./dynamodb/installer");
var starter_1 = require("./dynamodb/starter");
var utils_1 = require("./dynamodb/utils");
var config_1 = require("./dynamodb/config");
var DynamodbLocalManager = /** @class */ (function () {
    function DynamodbLocalManager() {
        this.dbInstances = {};
        this.config = new config_1.Config();
    }
    DynamodbLocalManager.prototype.install = function (callback) {
        var installer = new installer_1.Installer();
        installer.install(this.config, function (msg) {
            console.log(msg);
            callback();
        });
    };
    DynamodbLocalManager.prototype.start = function (optional_config) {
        var starter = new starter_1.Starter();
        var starting_config = this.config;
        if (optional_config)
            starting_config = optional_config;
        console.log("Configuration used for this instance is:" + starting_config);
        var instance = starter.start(starting_config);
        this.dbInstances[instance.port] = {
            process: instance.proc,
            config: starting_config
        };
        instance.proc.on('close', function (code) {
            if (code !== null && code !== 0) {
                console.log('DynamoDB Local failed to start with code', code);
            }
        });
        console.log('Dynamodb Local Started, Visit: http://localhost:' + (this.config.port) + '/shell');
    };
    DynamodbLocalManager.prototype.stop = function (port) {
        if (this.dbInstances[port]) {
            this.dbInstances[port].process.kill('SIGKILL');
            delete this.dbInstances[port];
        }
    };
    DynamodbLocalManager.prototype.restart = function (port) {
        var restart_config = this.dbInstances[port].config;
        this.stop(port);
        this.start(restart_config);
        console.log('Successfully restarted dynamodb local on port: ' + port);
    };
    DynamodbLocalManager.prototype.remove = function () {
        var utils = new utils_1.Utils();
        utils.removeDir(this.config.install_path);
    };
    return DynamodbLocalManager;
}());
exports.DynamodbLocalManager = DynamodbLocalManager;
//# sourceMappingURL=index.js.map